use strict;
use warnings;
package Email::Pipemailer;
{
  $Email::Pipemailer::VERSION = '1.001';
}
# ABSTRACT: a thing that delivers mail received on STDIN (placeholder)


1;

__END__

=pod

=head1 NAME

Email::Pipemailer - a thing that delivers mail received on STDIN (placeholder)

=head1 VERSION

version 1.001

=head1 DESCRIPTION

This may be fleshed out more in the future.  For now, it is included to produce
a useful namespace for L<Email::Pipemailer::DieHandler>.

=head1 AUTHOR

Ricardo Signes <rjbs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Ricardo Signes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
